==> v3.12.4.8.tar.gz: qcad-3.12.4.8/ts/qcadgui_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>ExitTrialDialog</name>
    <message>
        <source>Trial Version</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Versão de Avaliação</translation>
    </message>
    <message>
        <source>QCAD Trial</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">QCAD versão de avaliação</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Cannot find user manual at: %1</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Não consegue encontrar o manual do usuário em: %1</translation>
    </message>
    <message>
        <source>Unable to launch Qt Assistant (%1)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Não é possível iniciar Qt Assistant (%1)</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+126"/>
        <source>Custom</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Customize..
Configurar...</translatorcomment>
        <translation>Personalizado</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+156"/>
        <source>Invalid</source>
        <translation>Inválido</translation>
    </message>
</context>
<context>
    <name>RSingleApplication</name>
    <message>
        <source>This software is not intended for production use.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Este software não se destina para uso em produção.</translation>
    </message>
    <message>
        <source>To continue trying out QCAD, please restart the software.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Para continuar a experimentar QCAD reinicie o software.</translation>
    </message>
    <message>
        <source>To start using QCAD without any limitations, please buy the full version for a small license fee from %1.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Para começar a usar o QCAD, sem quaisquer limitações, por favor, compre a versão completa de uma pequena taxa de licenciamento de %1.</translation>
    </message>
</context>
</TS>

==> v3.22.1.2.tar.gz: qcad-3.22.1.2/ts/qcadgui_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>ExitTrialDialog</name>
    <message>
        <source>Trial Version</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Versão de Avaliação</translation>
    </message>
    <message>
        <source>QCAD Trial</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">QCAD versão de avaliação</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Cannot find user manual at: %1</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Não consegue encontrar o manual do usuário em: %1</translation>
    </message>
    <message>
        <source>Unable to launch Qt Assistant (%1)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Não é possível iniciar Qt Assistant (%1)</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+126"/>
        <source>Custom</source>
        <translation>Personalizado</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+195"/>
        <source>Grid</source>
        <translation>Grade</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Final</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>Na Entidade</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Perpendicular</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>Tangencial</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Centro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Meio</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Interseção</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Referência</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+171"/>
        <source>Invalid</source>
        <translation>Inválido</translation>
    </message>
</context>
<context>
    <name>RSingleApplication</name>
    <message>
        <source>This software is not intended for production use.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Este software não se destina para uso em produção.</translation>
    </message>
    <message>
        <source>To continue trying out QCAD, please restart the software.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Para continuar a experimentar QCAD reinicie o software.</translation>
    </message>
    <message>
        <source>To start using QCAD without any limitations, please buy the full version for a small license fee from %1.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Para começar a usar o QCAD, sem quaisquer limitações, por favor, compre a versão completa de uma pequena taxa de licenciamento de %1.</translation>
    </message>
</context>
</TS>
